@@ -1,3 +1,5 @@
+use self::item::Position;
+
 use super::{
     definition::{
         Components, MediaType, OpenApi, Operation, Parameter, ParameterLocation, ParameterValue,
@@ -15,6 +17,8 @@ use schemars::{
 };
 use std::cell::RefCell;
 
+mod impls;
+
 pub mod item;
 
 pub type ItemFn = fn(&Options) -> Result<item::Item, Error>;
@@ -216,7 +220,7 @@ pub fn generate_with_options(options: Options) -> Result<OpenApi, Error> {
                 // TODO: checks
 
                 match binding.kind {
-                    BindingKind::Query | BindingKind::Path => {
+                    BindingKind::Query | BindingKind::Path | BindingKind::Header => {
                         let schema_obj = binding.schema.clone().into_object();
 
                         if let Some(obj) = schema_obj.object {
@@ -242,6 +246,7 @@ pub fn generate_with_options(options: Options) -> Result<OpenApi, Error> {
                                     location: match binding.kind {
                                         BindingKind::Query => ParameterLocation::Query,
                                         BindingKind::Path => ParameterLocation::Path,
+                                        BindingKind::Header => ParameterLocation::Header,
                                         BindingKind::Body => unreachable!(),
                                     },
                                     description: s
@@ -445,3 +450,21 @@ impl From<serde_json::Error> for ErrorKind {
         ErrorKind::SerdeJson(e)
     }
 }
+
+pub trait OperationInput {
+    fn operation_input(
+        opts: &Options,
+        id: &'static str,
+        position: Position,
+        route: item::Route,
+    ) -> Option<item::Item>;
+}
+
+pub trait OperationOutput {
+    fn operation_output(
+        opts: &Options,
+        id: &'static str,
+        position: Position,
+        route: item::Route,
+    ) -> Option<item::Item>;
+}
